==> openrpt-2.3.0-source.tar.bz2: openrpt-2.3.0-source/OpenRPT/renderer/renderer_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr">
<defaultcodec></defaultcodec>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="previewdialog.cpp" line="46"/>
        <source>Print Preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="63"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="64"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="53"/>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="58"/>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="openreports.cpp" line="1778"/>
        <source>Missing Report Parameter</source>
        <translation>Paramètre de rapport manquant</translation>
    </message>
    <message>
        <location filename="openreports.cpp" line="1778"/>
        <source>Enter in a value for the parameter &quot;%1&quot;:</source>
        <translation>Saisissez une valeur pour le paramètre &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="openreports_wrapper.cpp" line="541"/>
        <source>Report Definition Not Found</source>
        <translation>Définition de rapport non trouvée</translation>
    </message>
    <message>
        <location filename="openreports_wrapper.cpp" line="544"/>
        <source>The report definition for this report, &quot;%1&quot; cannot be found.
Please contact your Systems Administrator and report this issue.</source>
        <translation>La définition du rapport &quot;%1&quot; est introuvable.
Contactez s&apos;il vous plait votre Administrateur Système et rapportez-lui ce problème.</translation>
    </message>
    <message>
        <location filename="openreports_wrapper.cpp" line="546"/>
        <source>Unknown Error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="openreports_wrapper.cpp" line="548"/>
        <source>An unknown error was encountered while processing your request.
Please contact your Systems Administrator and report this issue.</source>
        <translation>Une erreur inconnue s&apos;est produite pendant le traitement de votre requête.
Contactez s&apos;il vous plait votre Administrateur Système et rapportez-lui ce problème.</translation>
    </message>
</context>
</TS>

==> openrpt-3.2.2-source.tar.bz2: openrpt-3.2.2-source/OpenRPT/renderer/renderer_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr">
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="previewdialog.cpp" line="46"/>
        <source>Print Preview</source>
        <translation>Prévisualisation</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="64"/>
        <source>Print</source>
        <translation>Imprimer</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="53"/>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <location filename="previewdialog.cpp" line="58"/>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="openreports.cpp" line="1778"/>
        <source>Missing Report Parameter</source>
        <translation type="obsolete">Paramètre de rapport manquant</translation>
    </message>
    <message>
        <location filename="openreports.cpp" line="1778"/>
        <source>Enter in a value for the parameter &quot;%1&quot;:</source>
        <translation type="obsolete">Saisissez une valeur pour le paramètre &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="openreports.cpp" line="539"/>
        <source>Report Definition Not Found</source>
        <translation>Définition de rapport non trouvée</translation>
    </message>
    <message>
        <location filename="openreports.cpp" line="542"/>
        <source>The report definition for this report, &quot;%1&quot; cannot be found.
Please contact your Systems Administrator and report this issue.</source>
        <translation>La définition du rapport &quot;%1&quot; est introuvable.
Contactez s&apos;il vous plait votre Administrateur Système et rapportez-lui ce problème.</translation>
    </message>
    <message>
        <location filename="openreports.cpp" line="544"/>
        <source>Unknown Error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <location filename="openreports.cpp" line="546"/>
        <source>An unknown error was encountered while processing your request.
Please contact your Systems Administrator and report this issue.</source>
        <translation>Une erreur inconnue s&apos;est produite pendant le traitement de votre requête.
Contactez s&apos;il vous plait votre Administrateur Système et rapportez-lui ce problème.</translation>
    </message>
</context>
</TS>
